@@ -8,10 +8,11 @@ from __future__ import annotations
 
 import logging
 import sys
+from abc import ABC
 from collections import defaultdict
 from importlib.util import module_from_spec, spec_from_file_location
 from pathlib import Path
-from typing import TYPE_CHECKING, Iterable, Mapping, List, Dict
+from typing import TYPE_CHECKING, Iterable, Mapping, Any, List, Dict
 
 from .commands import Command
 from .context import Context
@@ -48,7 +49,7 @@ def render_command_rst(command: CommandCls, fix_name: Bool = True, fix_name_func
     :return: The help text for the given Command, formatted using RST
     """
     with Context([], command, allow_argv_prog=False):
-        return get_formatter(command).format_rst(fix_name, fix_name_func, no_sys_argv=True)
+        return get_formatter(command).format_rst(fix_name, fix_name_func)
 
 
 def _render_commands_rst(commands: Commands, fix_name: Bool = True, fix_name_func: NameFunc = None) -> str:
@@ -72,7 +73,7 @@ def _render_commands_rst(commands: Commands, fix_name: Bool = True, fix_name_fun
 # region Import and Load Commands
 
 
-def load_commands(path: PathLike, top_only: Bool = False) -> Commands:
+def load_commands(path: PathLike, top_only: Bool = False, include_abc: Bool = False) -> Commands:
     """
     Load all of the commands from the file with the given path and return them as a dict of ``{name: Command}``.
 
@@ -82,22 +83,29 @@ def load_commands(path: PathLike, top_only: Bool = False) -> Commands:
 
     :param path: The path to a file containing one or more :class:`.Command` classes
     :param top_only: If True, then only top-level commands are returned (default: all)
+    :param include_abc: Whether Command classes that extend :class:`python:abc.ABC` should be included in results.
     :return: Dict containing the Commands loaded from the given file
     """
     with Context(allow_argv_prog=False):
         module = import_module(path)
-    commands = {key: val for key, val in module.__dict__.items() if not key.startswith('__') and _is_command(val)}
-    if top_only:
-        commands = top_level_commands(commands)
 
-    doc_str = module.__doc__
-    if doc_str:
+    commands = filtered_commands(module.__dict__, top_only, include_abc)
+
+    if doc_str := module.__doc__:
         for command in commands.values():
             get_metadata(command).pkg_doc_str = doc_str
 
     return commands
 
 
+def filtered_commands(obj_map: Dict[str, Any], top_only: Bool = False, include_abc: Bool = False) -> Commands:
+    commands = {key: val for key, val in obj_map.items() if not key.startswith('__') and _is_command(val, include_abc)}
+    if top_only:
+        commands = top_level_commands(commands)
+
+    return commands
+
+
 def top_level_commands(commands: Commands) -> Commands:
     """Filter the given commands to only the ones that do not have a parent present in the provided dict of commands"""
     if len(commands) <= 1:
@@ -105,8 +113,7 @@ def top_level_commands(commands: Commands) -> Commands:
 
     indirect_parents = defaultdict(set)
     for name, command in commands.items():
-        sub_command = get_params(command).sub_command
-        if sub_command:
+        if sub_command := get_params(command).sub_command:
             for choice in sub_command.choices.values():
                 indirect_parents[choice.target].add(command)
 
@@ -142,8 +149,11 @@ def import_module(path: PathLike):
     return module
 
 
-def _is_command(obj) -> bool:
-    return isinstance(obj, CommandMeta) and obj is not Command
+def _is_command(obj, include_abc: Bool = False) -> bool:
+    if not (isinstance(obj, CommandMeta) and obj is not Command):
+        return False
+    else:
+        return True if include_abc else ABC not in obj.__bases__
 
 
 # endregion
@@ -238,7 +248,9 @@ class RstWriter:
         names = [self.document_script(path, subdir, top_only=top_only, **kwargs) for path in paths]
         if index_name or index_header or index_subdir:
             name = index_name or subdir
-            self.write_index(name, index_header or name.title(), names, subdir, caption, index_subdir)
+            self.write_index(
+                name, index_header or name.title(), names, content_subdir=subdir, caption=caption, subdir=index_subdir
+            )
 
     def document_module(self, module: str, subdir: str = None):
         """
@@ -263,6 +275,7 @@ class RstWriter:
         index: Bool = True,
         empty: Bool = False,
         caption: str = None,
+        max_depth: int = 4,
     ) -> List[str]:
         """
         :param pkg_name: The name of the package to document
@@ -273,6 +286,7 @@ class RstWriter:
         :param index: Whether the index file should be created
         :param empty: Whether an index file should be created if the package had no modules to document
         :param caption: A caption to use for the index
+        :param max_depth: The maximum depth of the table of contents tree.  Use ``-1`` to allow unlimited depth.
         :return: List of the names from the contents of the package
         """
         if name:
@@ -281,23 +295,31 @@ class RstWriter:
             index_subdir = None
             content_subdir = subdir
 
-        contents = self._generate_code_rsts(pkg_name, pkg_path, content_subdir)
+        # TODO: This needs improvement for multi-package repos
+        contents = self._generate_code_rsts(pkg_name, pkg_path, content_subdir, max_depth=max_depth)
         if (not contents and not empty) or not index:
             return contents
 
         if not header:
-            header = '{} Package'.format(pkg_name.split('.')[-1].title())
+            header = f'{pkg_name.split(".")[-1].title()} Package'
 
-        self.write_index(name or pkg_name, header, contents, index_subdir, caption=caption, subdir=subdir)
+        self.write_index(
+            name=name or pkg_name,
+            header=header,
+            contents=contents,
+            content_subdir=index_subdir,
+            caption=caption,
+            subdir=subdir,
+            max_depth=max_depth,
+        )
         return contents
 
-    def _generate_code_rsts(self, pkg_name: str, pkg_path: Path, subdir: str = None) -> List[str]:
+    def _generate_code_rsts(self, pkg_name: str, pkg_path: Path, subdir: str = None, max_depth: int = 4) -> List[str]:
         contents = []
         for path in pkg_path.iterdir():
             if path.is_dir():
                 sub_pkg_name = f'{pkg_name}.{path.name}'
-                pkg_modules = self.document_package(sub_pkg_name, path, subdir)
-                if pkg_modules:
+                if self.document_package(sub_pkg_name, path, subdir, max_depth=max_depth):
                     contents.append(sub_pkg_name)
             elif path.is_file() and path.suffix == '.py' and not path.name.startswith('__'):
                 name = f'{pkg_name}.{path.stem}'
@@ -313,12 +335,29 @@ class RstWriter:
         name: str,
         header: str,
         contents: Strings,
+        *,
         content_subdir: str = None,
-        caption: str = None,
         subdir: str = None,
+        caption: str = None,
+        max_depth: int = 4,
+        **kwargs,
     ):
+        """
+        Write an RST index file with a table of contents that references one or more other documents.
+
+        :param name: The file name to use when saving this index.
+        :param header: The name of the index document.  Written as a header above the ``toctree`` directive.
+        :param contents: The names of the documents to include in the table of contents for this index.
+        :param content_subdir: The subdirectory that contains the RST files referenced by ``contents``, if any / not
+          included in the ``contents`` values already.
+        :param subdir: The output subdirectory to use when writing this index, if any.
+        :param caption: A caption to use for the index
+        :param max_depth: The maximum depth of the table of contents tree.  Use ``-1`` to allow unlimited depth.
+        :param kwargs: Additional keyword arguments to be included as ``:key: <value>`` options to the ``toctree``
+          directive.
+        """
         content_fmt = '    {}' if content_subdir is None else f'    {content_subdir}/{{}}'
-        rendered = rst_toc_tree(header, content_fmt, contents, caption=caption)
+        rendered = rst_toc_tree(header, content_fmt, contents, caption=caption, max_depth=max_depth, **kwargs)
         self.write_rst(name, rendered, subdir)
 
     def write_rst(self, name: str, content: str, subdir: str = None):
@@ -330,6 +369,6 @@ class RstWriter:
         path = target_dir.joinpath(name + self.ext)
         log.debug(f'{prefix} {path.as_posix()}')
         if not self.dry_run:
-            # Path.write_text on 3.7 does not support `newline`
+            # Path.write_text on 3.8 does not support `newline`
             with path.open('w', encoding=self.encoding, newline=self.newline) as f:
                 f.write(content)
