@@ -54,6 +54,13 @@ def rst_header(text: str, level: int = 1, overline: Bool = False) -> str:
     return f'{bar}\n{text}\n{bar}' if overline else f'{text}\n{bar}'
 
 
+def spaced_rst_header(text: str, level: int = 1, before: bool = True) -> Iterator[str]:
+    if before:
+        yield ''
+    yield f'{text}\n{rst_bar(text, level)}'
+    yield ''
+
+
 def _rst_directive(
     directive: str, args: str = None, options: Dict[str, Any] = None, indent: int = 4, check: Bool = False
 ) -> Iterator[str]:
@@ -81,6 +88,15 @@ def _rst_toc_tree(name: str, content_fmt: str, contents: Strings, max_depth: int
 
 
 def rst_toc_tree(name: str, content_fmt: str, contents: Strings, max_depth: int = 4, **kwargs) -> str:
+    """
+    :param name: The name of the section.  Written as a header above the ``toctree`` directive.
+    :param content_fmt: The format string used to indent/prefix each entry in the contents to include in this table
+      of contents.
+    :param contents: The names of the documents to include in this table of contents.
+    :param max_depth: The maximum depth of the table of contents tree.  Use ``-1`` to allow unlimited depth.
+    :param kwargs: Keyword arguments to be included as ``:key: <value>`` options to the ``toctree`` directive.
+    :return: The RST header and table of contents directive as a string.
+    """
     return '\n'.join(_rst_toc_tree(name, content_fmt, contents, max_depth, **kwargs))
 
 
