@@ -14,7 +14,7 @@ from inspect import getmodule
 from pathlib import Path
 from sys import modules
 from textwrap import dedent
-from typing import TYPE_CHECKING, Any, Type, Optional, Union, Tuple, Dict
+from typing import TYPE_CHECKING, Any, Type, Callable, Optional, Union, Tuple, Dict
 from urllib.parse import urlparse
 
 from .context import ctx, NoActiveContext
@@ -30,11 +30,14 @@ DEFAULT_FILE_NAME: str = 'UNKNOWN'
 #  CLI module
 
 
-class Metadata:
-    __slots__ = ('default', 'name')
+# region Metadata Descriptors
 
-    def __init__(self, default):
-        self.default = default
+
+class MetadataBase:
+    __slots__ = ('name', 'inheritable')
+
+    def __init__(self, inheritable: bool = True):
+        self.inheritable = inheritable
 
     def __set_name__(self, owner: Type[ProgramMetadata], name: str):
         self.name = name
@@ -47,28 +50,75 @@ class Metadata:
             return instance.__dict__[self.name]
         except KeyError:
             pass
-        try:
-            return getattr(instance.parent, self.name)
-        except AttributeError:  # parent is None
-            return self.default
+        if self.inheritable:
+            try:
+                return getattr(instance.parent, self.name)
+            except AttributeError:  # parent is None
+                pass
+        return self.get_value(instance)
 
     def __set__(self, instance: ProgramMetadata, value: Union[str, Path, None]):
         if value is not None:
             instance.__dict__[self.name] = value
 
+    def get_value(self, instance: ProgramMetadata):
+        raise NotImplementedError
+
+
+class Metadata(MetadataBase):
+    __slots__ = ('default',)
+
+    def __init__(self, default, inheritable: bool = True):
+        super().__init__(inheritable)
+        self.default = default
+
+    def get_value(self, instance: ProgramMetadata):
+        return self.default
+
     def __repr__(self) -> str:
         return f'Metadata(default={self.default!r})'
 
 
+class DynamicMetadata(MetadataBase):
+    __slots__ = ('func', 'cache_result')
+
+    def __init__(self, func: Callable[[ProgramMetadata], Any], cache_result: bool = True, inheritable: bool = True):
+        super().__init__(inheritable)
+        self.func = func
+        self.cache_result = cache_result
+
+    def get_value(self, instance: ProgramMetadata):
+        result = self.func(instance)
+        if self.cache_result:
+            instance.__dict__[self.name] = result
+        return result
+
+    def __repr__(self) -> str:
+        return f'DynamicMetadata(func={getattr(self.func, "__qualname__", self.func)})'
+
+
+def dynamic_metadata(func=None, *, cache_result: bool = True, inheritable: bool = True):
+    if func is None:
+
+        def _dynamic_metadata(func):
+            return DynamicMetadata(func, cache_result, inheritable)
+
+        return _dynamic_metadata
+    else:
+        return DynamicMetadata(func, cache_result, inheritable)
+
+
+# endregion
+
+
 class ProgramMetadata:
     _fields = {'parent'}
     parent: Optional[ProgramMetadata] = None
     path: Path = Metadata(None)
     package: str = Metadata(None)
     module: str = Metadata(None)
+    cmd_module: str = Metadata(None)
     command: str = Metadata(None)
-    prog: str = Metadata(None)
-    prog_src: str = Metadata(None)
     url: str = Metadata(None)
     docs_url: str = Metadata(None)
     email: str = Metadata(None)
@@ -76,7 +126,6 @@ class ProgramMetadata:
     usage: str = Metadata(None)
     description: str = Metadata(None)
     epilog: str = Metadata(None)
-    doc_name: str = Metadata(None)
     doc_str: str = Metadata('')
     pkg_doc_str: str = Metadata('')  # Set by :func:`~.documentation.load_commands` to capture package docstrings
 
@@ -108,25 +157,23 @@ class ProgramMetadata:
         description: str = None,
         epilog: str = None,
         doc_name: str = None,
-        no_sys_argv: Bool = None,
     ) -> ProgramMetadata:
         path, g = _path_and_globals(command, path)
-        if command.__module__ != 'cli_command_parser.commands':
+        if (cmd_module := command.__module__) != 'cli_command_parser.commands':
             # Prevent inheritors from getting docstrings from the base Command
             doc_str = g.get('__doc__')
             doc = command.__doc__
         else:
             doc = doc_str = None
 
-        prog, prog_src = _prog_finder.normalize(prog, path, parent, no_sys_argv, command)
         return cls(
             parent=parent,
             path=path,
             package=g.get('__package__'),
             module=g.get('__module__'),
+            cmd_module=cmd_module,
             command=command.__qualname__,
             prog=prog,
-            prog_src=prog_src,
             url=url or g.get('__url__'),
             docs_url=docs_url or _docs_url_from_repo_url(url) or _docs_url_from_repo_url(g.get('__url__')),
             email=email or g.get('__author_email__'),
@@ -134,38 +181,70 @@ class ProgramMetadata:
             usage=usage,
             description=_description(description, doc),
             epilog=epilog,
-            doc_name=_doc_name(doc_name, path, prog),
+            doc_name=doc_name,
             doc_str=doc_str,
         )
 
     def __repr__(self) -> str:
         return _repr(self)
 
-    def format_epilog(self, extended: Bool = True) -> str:
+    # region Program Name Properties
+
+    @cached_property
+    def _prog_and_src(self) -> Tuple[str, str]:
+        if prog := self.__dict__.get('prog'):
+            return prog, 'class kwargs'
+        return _prog_finder.normalize(self.path, self.parent, None, self.cmd_module, self.command)
+
+    @dynamic_metadata(cache_result=False)
+    def prog(self) -> str:
+        return self._prog_and_src[0]
+
+    @cached_property
+    def _doc_prog_and_src(self) -> Tuple[str, str]:
+        if prog := self.__dict__.get('prog'):
+            return prog, 'class kwargs'
+        return _prog_finder.normalize(self.path, self.parent, False, self.cmd_module, self.command)
+
+    def get_prog(self, allow_sys_argv: Bool = None) -> str:
+        return self._get_prog(allow_sys_argv)[0]
+
+    def _get_prog(self, allow_sys_argv: Bool = None) -> Tuple[str, str]:
+        return self._prog_and_src if allow_sys_argv or allow_sys_argv is None else self._doc_prog_and_src
+
+    @dynamic_metadata(inheritable=False)
+    def doc_name(self) -> str:
+        return Path(self._doc_prog_and_src[0]).stem
+
+    # endregion
+
+    def format_epilog(self, extended: Bool = True, allow_sys_argv: Bool = None) -> str:
         parts = [self.epilog] if self.epilog else []
         if parts and not extended:
             return parts[0]
 
-        version = self.version
-        if version:
+        if version := self.version:
             version = f' [ver. {version}]'
         if self.email:
-            parts.append(f'Report {self.prog}{version} bugs to {self.email}')
-        url = self.docs_url or self.url
-        if url:
+            parts.append(f'Report {self.get_prog(allow_sys_argv)}{version} bugs to {self.email}')
+        if url := self.docs_url or self.url:
             parts.append(f'Online documentation: {url}')
         return '\n\n'.join(parts)
 
-    def get_doc_str(self, strip: bool = True) -> OptStr:
-        doc_str = self.pkg_doc_str
-        if doc_str and strip:
+    def get_doc_str(self, strip: Bool = True) -> OptStr:
+        if (doc_str := self.pkg_doc_str) and strip:
             doc_str = doc_str.strip()
         if not doc_str:
-            doc_str = self.doc_str
-            if doc_str and strip:
+            if (doc_str := self.doc_str) and strip:
                 doc_str = doc_str.strip()
         return doc_str
 
+    def get_description(self, allow_inherited: Bool = True) -> OptStr:
+        if description := self.description:
+            if not allow_inherited and (parent := self.parent) and (parent_description := parent.description):  # noqa
+                return description if parent_description != description else None
+        return description
+
 
 def _repr(obj, indent=0) -> str:
     if not isinstance(obj, ProgramMetadata):
@@ -194,56 +273,53 @@ class ProgFinder:
     @classmethod
     def _get_console_scripts(cls) -> Tuple[EntryPoint, ...]:
         try:
-            return entry_points(group='console_scripts')
+            return entry_points(group='console_scripts')  # noqa
         except TypeError:  # Python 3.8 or 3.9
             return entry_points()['console_scripts']
 
     def normalize(
         self,
-        prog: OptStr,
         cmd_path: Path,
         parent: Optional[ProgramMetadata],
-        no_sys_argv: Bool,
-        command: CommandType,
+        allow_sys_argv: Bool,
+        cmd_module: str,
+        cmd_name: str,
     ) -> Tuple[OptStr, str]:
-        if prog:
-            return prog, 'class kwargs'
-
-        ep_name = self._from_entry_point(command)
-        # TODO: This isn't working for documentation generation...
-        if ep_name:
+        if ep_name := self._from_entry_point(cmd_module, cmd_name):
             return ep_name, 'entry_points'
 
-        if no_sys_argv is None:
+        if allow_sys_argv is None:
             try:
-                no_sys_argv = not ctx.allow_argv_prog
+                allow_sys_argv = ctx.allow_argv_prog
             except NoActiveContext:
-                no_sys_argv = False
+                allow_sys_argv = True
 
-        if parent and parent.prog != parent.path.name and (not no_sys_argv or parent.prog_src != 'sys.argv'):
-            return parent.prog, parent.prog_src
-        elif not no_sys_argv:
-            argv_name = self._from_sys_argv()
-            if argv_name:
-                return argv_name, 'sys.argv'
+        if parent:
+            p_prog, p_src = parent._get_prog(allow_sys_argv)
+            if p_prog and p_src != 'path':
+                return p_prog, p_src
+
+        if allow_sys_argv and (argv_name := self._from_sys_argv()):
+            return argv_name, 'sys.argv'
 
         return cmd_path.name, 'path'
 
-    def _from_entry_point(self, command: CommandType) -> OptStr:
+    def _from_entry_point(self, cmd_module: str, cmd_name: str) -> OptStr:
+        # TODO: Verify whether this is working for documentation generation...
         main_mod = 'cli_command_parser.commands'
-        for prog, obj, obj_mod, obj_name in self._iter_entry_point_candidates(command):
-            if obj is command or (obj_mod == main_mod and obj_name == 'main'):
+        for prog, obj, obj_mod, obj_name in self._iter_entry_point_candidates(cmd_module):
+            if (obj_name == cmd_name and obj_mod == cmd_module) or (obj_mod == main_mod and obj_name == 'main'):
                 return prog
 
         return None
 
-    def _iter_entry_point_candidates(self, command: CommandType):
+    def _iter_entry_point_candidates(self, cmd_module: str):
         try:
             # TODO: This likely won't work for a base command in one module, sub commands defined in separate modules,
             #  and main imported from cli_command_parser in the package's __init__/__main__ module...
-            obj_prog_map = self.mod_obj_prog_map[command.__module__]
-            module = modules[command.__module__]
-        except KeyError as e:
+            obj_prog_map = self.mod_obj_prog_map[cmd_module]
+            module = modules[cmd_module]
+        except KeyError:
             pass
         else:
             for obj_name, prog in obj_prog_map.items():
@@ -253,7 +329,7 @@ class ProgFinder:
                 except AttributeError:
                     pass
                 else:
-                    yield prog, obj, getattr(obj, '__module__', ''), getattr(obj, '__name__', '')
+                    yield prog, obj, getattr(obj, '__module__', ''), getattr(obj, '__qualname__', '')
 
     def _from_sys_argv(self) -> OptStr:
         try:
@@ -311,9 +387,3 @@ def _docs_url_from_repo_url(repo_url: Optional[str]) -> Optional[str]:
             return f'https://{user}.github.io/{repo}/'
 
     return None
-
-
-def _doc_name(doc_name: Optional[str], path: Path, prog: str) -> str:
-    if doc_name:
-        return doc_name
-    return Path(prog).stem
